PyEci
=====

.. currentmodule:: cysgp4

.. autoclass:: PyEci
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyEci.geo_loc
      ~PyEci.loc
      ~PyEci.pydt
      ~PyEci.vel

   .. rubric:: Methods Summary

   .. autosummary::

      ~PyEci.update

   .. rubric:: Attributes Documentation

   .. autoattribute:: geo_loc
   .. autoattribute:: loc
   .. autoattribute:: pydt
   .. autoattribute:: vel

   .. rubric:: Methods Documentation

   .. automethod:: update
